#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagstream-conduit
version:              0.5.6
visibility:           public
id:                   tagstream-conduit-0.5.6-Lq31jSVIQguDEJildAbAwD
key:                  tagstream-conduit-0.5.6-Lq31jSVIQguDEJildAbAwD
license:              BSD-3-Clause
maintainer:           yi.codeplayer@gmail.com
author:               yihuang
homepage:             http://github.com/yihuang/tagstream-conduit
synopsis:             streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.

category:             Web, Conduit
abi:                  ead9182227992306a11676e117c8be8c
exposed:              True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Entities Text.HTML.TagStream.Text
    Text.HTML.TagStream.Types Text.HTML.TagStream.Utils

import-dirs:          /usr/lib/ghc-8.10.5/site-local/tagstream-conduit-0.5.6
library-dirs:         /usr/lib/ghc-8.10.5/site-local/tagstream-conduit-0.5.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/tagstream-conduit-0.5.6
hs-libraries:         HStagstream-conduit-0.5.6-Lq31jSVIQguDEJildAbAwD
depends:
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE
    conduit-extra-1.3.5-6wbdzvOjyuAGkpGhMnpbur
    data-default-0.7.1.1-5u8NwVJ9HGT30K0bkKsBOX
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe text-1.2.4.1
    transformers-0.5.6.2 xml-conduit-1.9.1.1-5pCpotf51DzBhLZtCry6QK

haddock-interfaces:
    /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock

haddock-html:         /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

